@@ -3,7 +3,8 @@ from django.conf.urls.defaults import patterns, url
 from downloads.views import object_list, download_request
 
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     # download url
     url(
         r'^$',
